@@ -27,7 +27,8 @@ OC.L10N.register(
     "Categories" : "Kategorije",
     "No notes yet" : "Još nema bilješki",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalirajte aplikaciju na svoj mobilni telefon kako biste s bilo kojeg mjesta mogli pristupiti svojim bilješkama.",
-    "Details" : "Pojedinosti",
+    "Share" : "Share",
+    "Rename" : "Rename",
     "Delete note" : "Izbriši bilješku",
     "Remove from favorites" : "Ukloni iz favorita",
     "Add to favorites" : "Dodaj u favorite",
@@ -53,19 +54,8 @@ OC.L10N.register(
     "Last week" : "Prošli tjedan",
     "This month" : "Ovaj mjesec",
     "Last month" : "Prošli mjesec",
-    "Category" : "Kategorija",
-    "Uncategorized" : "Nekategorizirani",
-    "Set category" : "Postavi kategoriju",
-    "Click here to save manually" : "Kliknite ovdje za ručno spremanje",
-    "Saving failed!" : "Spremanje nije uspjelo!",
-    "Last modified: {date}" : "Posljednja izmjena: {date}",
-    "Note has unsaved changes" : "Bilješka ima nespremljene promjene",
-    "Subcategory" : "Potkategorija",
-    "_%n word_::_%n words_" : ["%n riječ","%n riječi","%n riječi"],
-    "_%n character_::_%n characters_" : ["%n znak","%n znaka","%n znakova"],
     "Use Markdown markups to style your text." : "Za oblikovanje teksta upotrijebite oznake Markdown.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Započnite pisati bilješku klikom na „{newnote}” u navigaciji aplikacije.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Možete kreirati potkategorije korištenjem \"/\" kao odjeljivača između nadređene kategorije i potkategorije, npr. “{parent}/{sub}”.",
     "Note not found." : "Bilješka nije pronađena.",
     "Note is locked." : "Bilješka je zaključana.",
     "Insufficient storage." : "Nedovoljno prostora za pohranu.",
@@ -84,6 +74,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Postavljanje favorita za bilješku {id} nije uspjelo.",
     "Updating the note's category has failed. Is the target directory writable?" : "Ažuriranje kategorije bilješke nije uspjelo. Može li se pisati u ciljni direktorij?",
     "Updating the category for note {id} has failed." : "Ažuriranje kategorije za bilješku {id} nije uspjelo.",
+    "Uncategorized" : "Nekategorizirani",
     "Tasks" : "Zadaci",
     "Development Mode" : "Razvojni način rada",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Čini se da je aplikacija za upravljanje bilješkama instalirana iz razvojnog izvora. Instalirajte je iz trgovine aplikacija <a href=\"%1$s\">Nextcloud App Store</a>. Ako želite sami izraditi aplikaciju Notes, slijedite <a href=“%2$s“>upute za razvojne inženjere</a>."
