@@ -4,7 +4,8 @@ OC.L10N.register(
     "Notes" : "កំណត់​ចំណាំ",
     "Error" : "កំហុស",
     "New note" : "កំណត់​ចំណាំ​ថ្មី",
-    "Details" : "ព័ត៌មាន​លម្អិត",
+    "Share" : "ចែក​រំលែក",
+    "Rename" : "Rename",
     "Delete note" : "លុប​កំណត់​ចំណាំ",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
