@@ -2,7 +2,8 @@ OC.L10N.register(
     "notes",
     {
     "Error" : "ຜິດພາດ",
-    "Details" : "ລາຍລະອຽດ",
+    "Share" : "ເເບ່ງປັນ",
+    "Rename" : "ປ່ຽນຊື່",
     "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
     "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
     "Edit" : "ແກ້ໄຂ",
