@@ -6,7 +6,7 @@ OC.L10N.register(
     "Error" : "Klaida",
     "New note" : "Nauji užrašai",
     "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
-    "Help" : "Pagalba",
+    "Notes settings" : "Užrašų nustatymai",
     "Please see Nextcloud server log for details." : "Išsamesnei informacijai žiūrėkite Nextcloud serverio žurnalą.",
     "Deleted {title}" : "{title} ištrinti",
     "Undo Delete" : "Atšaukti ištrynimą",
@@ -15,33 +15,24 @@ OC.L10N.register(
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Atkurti {number} užrašai","Atkurti {number} užrašai","Atkurta {number} užrašų","Atkurti {number} užrašai"],
     "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
     "Organize your notes in categories." : "Skirstykite užrašus po kategorijas.",
-    "Use Markdown markups to style your text." : "Naudokite „Markdown“ ženklinimo kalbą, kad taisytumėte teksto stilių.",
-    "Action" : "Veiksmas",
-    "Insert image" : "Įterpti paveikslą",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Pradėkite rašyti užrašus, spusteldami ant mygtuko „{newnote}“.",
-    "Notes settings" : "Užrašų nustatymai",
     "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
     "File extension for new notes" : "Naujų užrašų failo prievardis",
     "Display mode for notes" : "Užrašų rodinio veiksena",
+    "Action" : "Veiksmas",
     "User defined" : "Naudotojo apibrėžtas",
     "Open in edit mode" : "Atverti redagavimo veiksenoje",
     "Open in preview mode" : "Atverti peržiūros veiksenoje",
+    "Insert link" : "Įterpti nuorodą",
+    "Insert image" : "Įterpti paveikslą",
+    "Switch between editor and viewer" : "Perjungti tarp redaktoriaus ir žiūryklės",
+    "All notes" : "Visi užrašai",
+    "Categories" : "Kategorijos",
     "No notes yet" : "Kol kas užrašų nėra",
     "Select an image" : "Pasirinkite paveikslą",
     "Wrong image" : "Neteisingas paveikslas",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Įsidiekite programėlę mobiliajame telefone, kad visur turėtumėte prieigą prie savo užrašų.",
-    "All notes" : "Visi užrašai",
-    "Categories" : "Kategorijos",
-    "Loading …" : "Įkeliama…",
-    "Today" : "Šiandien",
-    "Yesterday" : "Vakar",
-    "This week" : "Šią savaitę",
-    "Last week" : "Praeitą savaitę",
-    "This month" : "Šį mėnesį",
-    "Last month" : "Praeitą mėnesį",
-    "Rename" : "Pervadinti",
-    "Note's title" : "Užrašų pavadinimas",
-    "Details" : "Išsamiau",
+    "Share" : "Share",
+    "Rename" : "Rename",
     "Delete note" : "Ištrinti užrašus",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
@@ -56,21 +47,20 @@ OC.L10N.register(
     "Note is read-only. You cannot change it." : "Užrašai yra tik skaitymui. Jūs negalite jų keisti.",
     "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
     "Error from Nextcloud server: {msg}" : "Klaida iš Nextcloud serverio: {msg}",
-    "Category" : "Kategorija",
-    "Uncategorized" : "Nekategorizuoti",
-    "Set category" : "Nustatyti kategoriją",
-    "Click here to save manually" : "Spustelėkite čia norėdami įrašyti rankiniu būdu",
-    "Saving failed!" : "Įrašymas nepavyko!",
-    "Last modified: {date}" : "Paskutinis modifikavimas: {date}",
-    "Note has unsaved changes" : "Užrašuose yra neįrašytų pakeitimų.",
-    "Subcategory" : "Subkategorija",
-    "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodis"],
-    "_%n character_::_%n characters_" : ["%n simbolis","%n simboliai","%n simbolių","%n simbolis"],
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Galite sukurti subkategorijas, naudodami \"/\" kaip skirtuką tarp viršesnės kategorijos ir subkategorijos, pvz., “{parent}/{sub}”.",
+    "Loading …" : "Įkeliama…",
+    "Today" : "Šiandien",
+    "Yesterday" : "Vakar",
+    "This week" : "Šią savaitę",
+    "Last week" : "Praeitą savaitę",
+    "This month" : "Šį mėnesį",
+    "Last month" : "Praeitą mėnesį",
+    "Use Markdown markups to style your text." : "Naudokite „Markdown“ ženklinimo kalbą, kad taisytumėte teksto stilių.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Pradėkite rašyti užrašus, spusteldami ant mygtuko „{newnote}“.",
     "Note not found." : "Užrašai nerasti.",
     "Note is locked." : "Užrašai užrakinti.",
     "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
     "Updating the note's category has failed. Is the target directory writable?" : "Nepavyko atnaujinti užrašų kategorijos. Ar paskirties katalogas yra skirtas rašymui?",
+    "Uncategorized" : "Nekategorizuoti",
     "Tasks" : "Užduotys",
     "Development Mode" : "Plėtotojo veiksena"
 },
