@@ -14,7 +14,7 @@ OC.L10N.register(
     "Undo Delete" : "Повернути вилучення",
     "Note recovered" : "Примітку відновлено",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
-    "_Deleted {number} note_::_Deleted {number} notes_" : ["Видалено {number} примітка","Видалено {number} приміток","Видалено {number} приміток","Вилучено {number} нотаток"],
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Вилучено {number} нотатку","Вилучено {number} нотатки","Вилучено {number} нотаток","Вилучено {number} нотаток"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатку","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
     "Basics" : "Простий",
     "Write down your thoughts without any distractions." : "Занотовуйте свої думки, не відволікаючись.",
@@ -61,8 +61,8 @@ OC.L10N.register(
     "Wrong image" : "Недійсне зображення",
     "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали сервера.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Встановіть мобільний застосунок для мобільного телефону, що дозволить отримувати доступ до нотаток звідусіль.",
-    "Android app: {notes}" : "Додаток для Android: {notes}",
-    "iOS app: {notes}" : "Додаток для iOS: {notes}",
+    "Android app: {notes}" : "Застосунок для Android: {notes}",
+    "iOS app: {notes}" : "Застосунок для iOS: {notes}",
     "Rich text editor" : "Редактор з форматуванням",
     "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Ви можете почати використовувати простий у користуванні редактор форматованого тексту, який дозволить вводити текст без службових символів позначення форматування.",
     "This option can also be changed later on in the Notes app settings." : "Цю опцію можна буде змінити пізніше у налаштуваннях Нотаток.",
