@@ -3,12 +3,12 @@ OC.L10N.register(
     {
     "Notes" : "Notes",
     "Error" : "ایرر",
-    "Help" : "مدد",
-    "Today" : "آج",
+    "Share" : "تقسیم",
     "Rename" : "Rename",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "تدوین کریں",
+    "Today" : "آج",
     "Tasks" : "کام"
 },
 "nplurals=2; plural=(n != 1);");
