@@ -7,10 +7,8 @@ namespace OCA\Notes\Service;
 use OCA\Notes\Db\Meta;
 
 class MetaNote {
-	/** @var Note */
-	public $note;
-	/** @var Meta */
-	public $meta;
+	public Note $note;
+	public Meta $meta;
 
 	public function __construct(Note $note, Meta $meta) {
 		$this->note = $note;
