@@ -167,9 +167,16 @@ class NoteUtil {
 		} elseif ($create) {
 			$folder = $this->root->newFolder($path);
 		}
+
 		if (!($folder instanceof Folder)) {
 			throw new NotesFolderException($path.' is not a folder');
 		}
+
+		if ($folder->isShared()) {
+			$folderName = $this->root->getNonExistingName($path);
+			$folder = $this->root->newFolder($folderName);
+		}
+
 		return $folder;
 	}
 
